@@ -3,8 +3,9 @@ use Object::Simple;
 
 sub m6 {
     my $self = shift;
-    return $self->SUPER::m6(0) + 2;
+    $self->SUPER::m6(@_) + 3
 }
 
 
+
 Object::Simple->build_class;
