@@ -1,4 +1,4 @@
 package M14;
-use Object::Simple;
+use Object::Simple(base => M17);
 
 Object::Simple->build_class;
